@@ -34,7 +34,7 @@ def check_for_new_chat(system: 'System', driver: AppDriver,
     _, current = change_state(system, driver, current, GUIState(State.MAIN))
     chat = driver.get_new_chat()
     if chat is not None:
-        current = change_state(system, driver, current, GUIState(State.CHAT, chat.name))
+        _, current = change_state(system, driver, current, GUIState(State.CHAT, chat.name))
         messages = driver.get_new_messages()
 
         for m in messages:
@@ -72,6 +72,7 @@ def execute_action(system: 'System', driver: AppDriver, current: GUIState) -> GU
 
 def change_state(system: 'System', driver: AppDriver, _from: GUIState, _to: GUIState) -> Tuple[int, GUIState]:
     """
+    meats of supbot brain, responsible for switching screen using a state machine
     performs appropriate actions on the gui to reach the target gui state
     Changes gui state and returns the updated state object depending on success or failure
     :param system: `System` object
@@ -87,7 +88,6 @@ def change_state(system: 'System', driver: AppDriver, _from: GUIState, _to: GUIS
             return 0, _to
 
     elif _to.state == State.CHAT:
-
         if _from.state == State.MAIN:
 
             if driver.click_on_chat(_to.info):
@@ -98,19 +98,31 @@ def change_state(system: 'System', driver: AppDriver, _from: GUIState, _to: GUIS
                     return 0, _to
                 else:
                     system.logger.debug("Didn't find chat {} in search, trying intent".format(_to.info))
-                    time.sleep(0.5)
                     driver.press_back()
-                    time.sleep(0.5)
                     driver.press_back()
 
-                    if re.search("\+\d{0,2}\d{10}", _to.info):
-                        if driver.chat_via_intent(_to.info):
-                            return 0, _to
+                    if re.search("\d{11,13}", _to.info):
+                        # todo if by chance this halts in between it will mess up the states
+                        if driver.search_chat("!temp") and driver.click_on_chat("!temp"):
+                            if driver.type_and_send(f"wa.me/{_to.info}") and driver.click_on_last_chat_link():
+                                if not driver.click_ok():
+                                    return 0, _to
+                                else:
+                                    system.logger.debug("{} not found in Whatsapp".format(_to.info))
+                            else:
+                                system.logger.warning("This could lead to state mismatch, "
+                                                      "if that happens contact the dev")
+                                driver.press_back()
+                        else:
+                            system.logger.debug("Please create an empty group with `!temp` name")
                     else:
-                        system.logger.debug("{} not a phone number".format(_to.info))
+                        system.logger.debug("{} not a valid phone number".format(_to.info))
 
-        elif _from.state == State.CHAT and _from.info != _to.info:
-            driver.press_back()
-            return change_state(system, driver, GUIState(State.MAIN), _to)
+        elif _from.state == State.CHAT:
+            if _from.info != _to.info:
+                driver.press_back()
+                return change_state(system, driver, GUIState(State.MAIN), _to)
+            else:
+                return 0, _to
 
     return 1, _from
